// Copyright (c) 2016, 2018, 2025, Oracle and/or its affiliates.  All rights reserved.
// This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
// Code generated. DO NOT EDIT.

// Generative AI Service Inference API
//
// OCI Generative AI is a fully managed service that provides a set of state-of-the-art, customizable large language models (LLMs) that cover a wide range of use cases for text generation, summarization, and text embeddings.
// Use the Generative AI service inference API to access your custom model endpoints, or to try the out-of-the-box models to /EN/generative-ai-inference/latest/ChatResult/Chat, /EN/generative-ai-inference/latest/GenerateTextResult/GenerateText, /EN/generative-ai-inference/latest/SummarizeTextResult/SummarizeText, and /EN/generative-ai-inference/latest/EmbedTextResult/EmbedText.
// To use a Generative AI custom model for inference, you must first create an endpoint for that model. Use the /EN/generative-ai/latest/ to /EN/generative-ai/latest/Model/ by fine-tuning an out-of-the-box model, or a previous version of a custom model, using your own data. Fine-tune the custom model on a /EN/generative-ai/latest/DedicatedAiCluster/. Then, create a /EN/generative-ai/latest/DedicatedAiCluster/ with an Endpoint to host your custom model. For resource management in the Generative AI service, use the /EN/generative-ai/latest/.
// To learn more about the service, see the Generative AI documentation (https://docs.oracle.com/iaas/Content/generative-ai/home.htm).
//

package generativeaiinference

import (
	"encoding/json"
	"fmt"
	"github.com/oracle/oci-go-sdk/v65/common"
	"strings"
)

// AssistantMessage Represents a single instance of assistant message.
// Note: When responding to a tool call, set `content` to `null` (not `""`).
// This ensures the model correctly processes tool call messages in multi-step interactions.
type AssistantMessage struct {

	// Contents of the chat message.
	Content []ChatContent `mandatory:"false" json:"content"`

	// An optional name for the participant. Provides the model information to differentiate between participants of the same role.
	Name *string `mandatory:"false" json:"name"`

	// The tool calls generated by the model, such as function calls.
	ToolCalls []ToolCall `mandatory:"false" json:"toolCalls"`
}

// GetContent returns Content
func (m AssistantMessage) GetContent() []ChatContent {
	return m.Content
}

func (m AssistantMessage) String() string {
	return common.PointerString(m)
}

// ValidateEnumValue returns an error when providing an unsupported enum value
// This function is being called during constructing API request process
// Not recommended for calling this function directly
func (m AssistantMessage) ValidateEnumValue() (bool, error) {
	errMessage := []string{}

	if len(errMessage) > 0 {
		return true, fmt.Errorf(strings.Join(errMessage, "\n"))
	}
	return false, nil
}

// MarshalJSON marshals to json representation
func (m AssistantMessage) MarshalJSON() (buff []byte, e error) {
	type MarshalTypeAssistantMessage AssistantMessage
	s := struct {
		DiscriminatorParam string `json:"role"`
		MarshalTypeAssistantMessage
	}{
		"ASSISTANT",
		(MarshalTypeAssistantMessage)(m),
	}

	return json.Marshal(&s)
}

// UnmarshalJSON unmarshals from json
func (m *AssistantMessage) UnmarshalJSON(data []byte) (e error) {
	model := struct {
		Content   []chatcontent `json:"content"`
		Name      *string       `json:"name"`
		ToolCalls []toolcall    `json:"toolCalls"`
	}{}

	e = json.Unmarshal(data, &model)
	if e != nil {
		return
	}
	var nn interface{}
	m.Content = make([]ChatContent, len(model.Content))
	for i, n := range model.Content {
		nn, e = n.UnmarshalPolymorphicJSON(n.JsonData)
		if e != nil {
			return e
		}
		if nn != nil {
			m.Content[i] = nn.(ChatContent)
		} else {
			m.Content[i] = nil
		}
	}
	m.Name = model.Name

	m.ToolCalls = make([]ToolCall, len(model.ToolCalls))
	for i, n := range model.ToolCalls {
		nn, e = n.UnmarshalPolymorphicJSON(n.JsonData)
		if e != nil {
			return e
		}
		if nn != nil {
			m.ToolCalls[i] = nn.(ToolCall)
		} else {
			m.ToolCalls[i] = nil
		}
	}
	return
}
